@@ -1,5 +1,5 @@
 import sh
-import sys
+from io import IOBase
 
 import unittest
 from unittest.mock import patch
@@ -171,14 +171,17 @@ class TestStepImplementerCreateContainerImageBuildah(BaseTSSCTestCase):
             }}
             run_step_test_with_result_validation(temp_dir, 'create-container-image', config, expected_step_results)
             buildah_mock.bud.assert_called_once_with(
+                '--storage-driver=vfs',
                 '--format=oci',
                 '--tls-verify=true',
                 '--layers',
                 '-f', file,
                 '-t', tag,
+                '--authfile', StringRegexParam(r".*/\.buildah-auth.json"),
                 temp_dir.path,
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase),
+                _tee='err'
             )
             buildah_mock.push.assert_called()
 
@@ -246,14 +249,17 @@ class TestStepImplementerCreateContainerImageBuildah(BaseTSSCTestCase):
                 config,
                 expected_step_results)
             buildah_mock.bud.assert_called_once_with(
+                '--storage-driver=vfs',
                 '--format=oci',
                 '--tls-verify=true',
                 '--layers',
                 '-f', file,
                 '-t', '{tag}'.format(tag=tag),
+                '--authfile', StringRegexParam(r".*/\.buildah-auth.json"),
                 temp_dir.path,
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase),
+                _tee='err'
             )
             buildah_mock.push.assert_called()
 
@@ -299,20 +305,25 @@ class TestStepImplementerCreateContainerImageBuildah(BaseTSSCTestCase):
             }}
             run_step_test_with_result_validation(temp_dir, 'create-container-image', config, expected_step_results)
             buildah_mock.bud.assert_called_once_with(
+                '--storage-driver=vfs',
                 '--format=oci',
                 '--tls-verify=true',
                 '--layers',
                 '-f', file,
                 '-t', tag,
+                '--authfile', StringRegexParam(r".*/\.buildah-auth.json"),
                 temp_dir.path,
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase),
+                _tee='err'
             )
             buildah_mock.push.assert_called_once_with(
+                '--storage-driver=vfs',
                 tag,
                 'docker-archive:{image_tar_file}'.format(image_tar_file=image_tar_file),
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase),
+                _tee='err'
             )
 
     @patch('sh.buildah', create=True)
@@ -395,20 +406,25 @@ class TestStepImplementerCreateContainerImageBuildah(BaseTSSCTestCase):
             }}
             run_step_test_with_result_validation(temp_dir, 'create-container-image', config, expected_step_results)
             buildah_mock.bud.assert_called_once_with(
+                '--storage-driver=vfs',
                 '--format=oci',
                 '--tls-verify=true',
                 '--layers',
                 '-f', file,
                 '-t', tag,
+                '--authfile', StringRegexParam(r".*/\.buildah-auth.json"),
                 temp_dir.path,
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase),
+                _tee='err'
             )
             buildah_mock.push.assert_called_once_with(
+                '--storage-driver=vfs',
                 tag,
                 'docker-archive:{image_tar_file}'.format(image_tar_file=image_tar_file),
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase),
+                _tee='err'
             )
 
     @patch('sh.buildah', create=True)
@@ -471,13 +487,16 @@ class TestStepImplementerCreateContainerImageBuildah(BaseTSSCTestCase):
             }}
             run_step_test_with_result_validation(temp_dir, 'create-container-image', config, expected_step_results)
             buildah_mock.bud.assert_called_once_with(
+                '--storage-driver=vfs',
                 '--format=oci',
                 '--tls-verify=true',
                 '--layers',
                 '-f', file,
                 '-t', tag,
+                '--authfile', StringRegexParam(r".*/\.buildah-auth.json"),
                 temp_dir.path,
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase),
+                _tee='err'
             )
             buildah_mock.push.assert_called()
